# OCSF Extensions Registry
The purpose of this file is to keep track of extensions and their uid's, so we
can avoid extension name and uid collisions.

| Extension Name | Type   | UID | Notes |
|----------------|--------|-----|-------|
| Splunk         | splunk | **1** | The Splunk schema extension |
| AWS            | aws_ex | **2** | The Amazon AWS schema extension |
| Development    | dev    | **999** | The development (TODO) schema extensions |
